"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildErrors = void 0;
const mustache_1 = require("mustache");
const path_1 = __importDefault(require("path"));
const config_1 = require("../config");
const utils_1 = require("./utils");
async function buildErrors(type) {
    const tpl = await utils_1.loadTemplate('error.tpl');
    const destDirPath = path_1.default.join(__dirname, '..', type);
    const items = [];
    const mapping = type === 'client' ? config_1.ClientErrorOptions : config_1.ServerErrorOptions;
    for (let key in mapping) {
        const fileName = mapping[key].statusCode + '-' + (mapping[key].code).toLowerCase().replaceAll('_', '-') + '.ts';
        const destFilePath = path_1.default.join(destDirPath + '/' + fileName);
        let className = key;
        const classErrorSuffix = key.toLocaleLowerCase().endsWith('error');
        if (!classErrorSuffix) {
            className += 'Error';
        }
        const content = mustache_1.render(tpl, {
            namespaceFile: 'index.ts',
            decorateMessage: type === 'server',
            logMessage: type === 'server',
            class: className,
            ...mapping[key]
        });
        await utils_1.saveFile(content, destFilePath);
        items.push({
            fileName,
            className,
            classErrorSuffix
        });
    }
    // default
    let content = items.map(item => {
        const parts = item.fileName.split('.');
        parts.pop();
        return `export * from "./${parts.join('.')}";`;
    }).reduce((prev, current) => prev + "\n" + current);
    let destFilePath = path_1.default.join(destDirPath + '/index.ts');
    await utils_1.saveFile(content, destFilePath);
    // bundle
    content = items
        .map(item => {
        const parts = item.fileName.split('.');
        parts.pop();
        const alias = item.classErrorSuffix ? item.className : item.className.substr(0, item.className.length - 5);
        return `export {${item.className} as ${alias}} from "./${parts.join('.')}";`;
    })
        .reduce((prev, current) => prev + "\n" + current);
    // += `\n` + `export {\n\t${aliases.join(`,\n\t`)}\n};`
    destFilePath = path_1.default.join(destDirPath + '/aliases.ts');
    await utils_1.saveFile(content, destFilePath);
}
exports.buildErrors = buildErrors;
//# sourceMappingURL=index.js.map